@@ -20,16 +20,15 @@ class Plugin(PluginParserBase):
         self.client = cyberspace.ZoomeyeClient(key)
         if "q" not in params:
             raise ParserExceptions.CyberSpace.Base("Missing query params: q")
-        query_str = parse.unquote_plus(params["q"][0])
-        max_page = int(parse.unquote_plus(
-            params["max_page"][0])) if "max_page" in params else 1
-        resources = parse.unquote_plus(
-            params["resources"][0]) if "resources" in params else "host"
+        query_str = params["q"][0]
+        max_page = int(
+            params["max_page"][0]) if "max_page" in params else 1
+        resources = params["resources"][0] if "resources" in params else "host"
         fields = "ip,port"
         data = []
         for ip, port in self.client.query(query_str, max_page, resources, fields):
             data.append(
-                    cyberspace.get_url_by_ip_port_domain(ip, port))
+                cyberspace.get_url_by_ip_port_domain(ip, port))
         return data
 
     def destruct(self):
